
## CATO-CLI - mutation.site.assignSiteBwLicense:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.assignSiteBwLicense) for documentation on this operation.

### Usage for mutation.site.assignSiteBwLicense:

```bash
catocli mutation site assignSiteBwLicense -h

catocli mutation site assignSiteBwLicense <json>

catocli mutation site assignSiteBwLicense --json-file mutation.site.assignSiteBwLicense.json

catocli mutation site assignSiteBwLicense '{"assignSiteBwLicenseInput":{"bw":1,"licenseId":"id","siteRefInput":{"by":"ID","input":"string"}}}'

catocli mutation site assignSiteBwLicense '{
    "assignSiteBwLicenseInput": {
        "bw": 1,
        "licenseId": "id",
        "siteRefInput": {
            "by": "ID",
            "input": "string"
        }
    }
}'
```

#### Operation Arguments for mutation.site.assignSiteBwLicense ####

